==> sdd.debin-jar-0.5.8.jar: ar/com/sdd/debin/entity/Debin.java <==
package ar.com.sdd.debin.entity;

import ar.com.sdd.commons.rest.util.ManyMillisecondsDateDeserializer;
import ar.com.sdd.commons.rest.util.ManyMillisecondsDateSerializer;
import ar.com.sdd.debin.core.DebinConst;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import java.math.BigDecimal;
import java.util.Date;

@JsonIgnoreProperties(ignoreUnknown=true)
public class Debin {

    private String id;
    private Estado estado;

    @JsonDeserialize(using = ManyMillisecondsDateDeserializer.class)
    @JsonSerialize(using = ManyMillisecondsDateSerializer.class)
    private Date addDt;

    @JsonDeserialize(using = ManyMillisecondsDateDeserializer.class)
    @JsonSerialize(using = ManyMillisecondsDateSerializer.class)
    private Date fechaExpiracion;

    private Creacion creacion;
    private Vendedor vendedor;
    private Comprador comprador;
    private DebinConst.Moneda moneda;
    private BigDecimal importe;
    private String concepto;

    @JsonDeserialize(using = ManyMillisecondsDateDeserializer.class)
    @JsonSerialize(using = ManyMillisecondsDateSerializer.class)
    private Date vencimiento;

    private BigDecimal montoPeriodo;
    private BigDecimal montoXDebin;
    private Integer cantidad;
    private String detalle;
    private String periodo;
    private String prestacion;
    private String referencia;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Estado getEstado() {
        return estado;
    }

    public void setEstado(Estado estado) {
        this.estado = estado;
    }

    public Date getAddDt() {
        return addDt;
    }

    public void setAddDt(Date addDt) {
        this.addDt = addDt;
    }

    public Date getFechaExpiracion() {
        return fechaExpiracion;
    }

    public void setFechaExpiracion(Date fechaExpiracion) {
        this.fechaExpiracion = fechaExpiracion;
    }

    public Creacion getCreacion() {
        return creacion;
    }

    public void setCreacion(Creacion creacion) {
        this.creacion = creacion;
    }

    public Vendedor getVendedor() {
        return vendedor;
    }

    public void setVendedor(Vendedor vendedor) {
        this.vendedor = vendedor;
    }

    public Comprador getComprador() {
        return comprador;
    }

    public void setComprador(Comprador comprador) {
        this.comprador = comprador;
    }

    public DebinConst.Moneda getMoneda() {
        return moneda;
    }

    public void setMoneda(DebinConst.Moneda moneda) {
        this.moneda = moneda;
    }

    public BigDecimal getImporte() {
        return importe;
    }

    public void setImporte(BigDecimal importe) {
        this.importe = importe;
    }

    public String getConcepto() {
        return concepto;
    }

    public void setConcepto(String concepto) {
        this.concepto = concepto;
    }

    public Date getVencimiento() {
        return vencimiento;
    }

    public void setVencimiento(Date vencimiento) {
        this.vencimiento = vencimiento;
    }

    public BigDecimal getMontoPeriodo() {
        return montoPeriodo;
    }

    public void setMontoPeriodo(BigDecimal montoPeriodo) {
        this.montoPeriodo = montoPeriodo;
    }

    public BigDecimal getMontoXDebin() {
        return montoXDebin;
    }

    public void setMontoXDebin(BigDecimal montoXDebin) {
        this.montoXDebin = montoXDebin;
    }

    public Integer getCantidad() {
        return cantidad;
    }

    public void setCantidad(Integer cantidad) {
        this.cantidad = cantidad;
    }

    public String getDetalle() {
        return detalle;
    }

    public void setDetalle(String detalle) {
        this.detalle = detalle;
    }

    public String getPeriodo() {
        return periodo;
    }

    public void setPeriodo(String periodo) {
        this.periodo = periodo;
    }

    public String getPrestacion() {
        return prestacion;
    }

    public void setPrestacion(String prestacion) {
        this.prestacion = prestacion;
    }

    public String getReferencia() {
        return referencia;
    }

    public void setReferencia(String referencia) {
        this.referencia = referencia;
    }

    @Override
    public String toString() {
        return "Debin ["
                + ((id != null) ? "id=" + id + ", " : "")
                + ((estado != null) ? "estado=" + estado + ", " : "")
                + ((addDt != null) ? "addDt=" + addDt + ", " : "")
                + ((fechaExpiracion != null) ? "fechaExpiracion=" + fechaExpiracion + ", " : "")
                + ((creacion != null) ? "creacion=" + creacion + ", " : "")
                + ((vendedor != null) ? "vendedor=" + vendedor + ", " : "")
                + ((comprador != null) ? "comprador=" + comprador + ", " : "")
                + ((moneda != null) ? "moneda=" + moneda + ", " : "")
                + ((importe != null) ? "importe=" + importe + ", " : "")
                + ((concepto != null) ? "concepto=" + concepto + ", " : "")
                + ((vencimiento != null) ? "vencimiento=" + vencimiento + ", " : "")
                + ((montoPeriodo != null) ? "montoPeriodo=" + montoPeriodo + ", " : "")
                + ((montoXDebin != null) ? "montoXDebin=" + montoXDebin + ", " : "")
                + ((cantidad != null) ? "cantidad=" + cantidad + ", " : "")
                + ((detalle != null) ? "detalle=" + detalle + ", " : "")
                + ((periodo != null) ? "periodo=" + periodo + ", " : "")
                + ((prestacion != null) ? "prestacion=" + prestacion + ", " : "")
                + ((referencia != null) ? "referencia=" + referencia : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Debin debin = (Debin) o;

        if (id != null ? !id.equals(debin.id) : debin.id != null) return false;
        if (estado != null ? !estado.equals(debin.estado) : debin.estado != null) return false;
        if (addDt != null ? !addDt.equals(debin.addDt) : debin.addDt != null) return false;
        if (fechaExpiracion != null ? !fechaExpiracion.equals(debin.fechaExpiracion) : debin.fechaExpiracion != null)
            return false;
        if (creacion != null ? !creacion.equals(debin.creacion) : debin.creacion != null) return false;
        if (vendedor != null ? !vendedor.equals(debin.vendedor) : debin.vendedor != null) return false;
        if (comprador != null ? !comprador.equals(debin.comprador) : debin.comprador != null) return false;
        if (moneda != debin.moneda) return false;
        if (importe != null ? !importe.equals(debin.importe) : debin.importe != null) return false;
        if (concepto != null ? !concepto.equals(debin.concepto) : debin.concepto != null) return false;
        if (vencimiento != null ? !vencimiento.equals(debin.vencimiento) : debin.vencimiento != null) return false;
        if (montoPeriodo != null ? !montoPeriodo.equals(debin.montoPeriodo) : debin.montoPeriodo != null) return false;
        if (montoXDebin != null ? !montoXDebin.equals(debin.montoXDebin) : debin.montoXDebin != null) return false;
        if (cantidad != null ? !cantidad.equals(debin.cantidad) : debin.cantidad != null) return false;
        if (detalle != null ? !detalle.equals(debin.detalle) : debin.detalle != null) return false;
        if (periodo != null ? !periodo.equals(debin.periodo) : debin.periodo != null) return false;
        if (prestacion != null ? !prestacion.equals(debin.prestacion) : debin.prestacion != null) return false;
        return referencia != null ? referencia.equals(debin.referencia) : debin.referencia == null;
    }

    @Override
    public int hashCode() {
        int result = id != null ? id.hashCode() : 0;
        result = 31 * result + (estado != null ? estado.hashCode() : 0);
        result = 31 * result + (addDt != null ? addDt.hashCode() : 0);
        result = 31 * result + (fechaExpiracion != null ? fechaExpiracion.hashCode() : 0);
        result = 31 * result + (creacion != null ? creacion.hashCode() : 0);
        result = 31 * result + (vendedor != null ? vendedor.hashCode() : 0);
        result = 31 * result + (comprador != null ? comprador.hashCode() : 0);
        result = 31 * result + (moneda != null ? moneda.hashCode() : 0);
        result = 31 * result + (importe != null ? importe.hashCode() : 0);
        result = 31 * result + (concepto != null ? concepto.hashCode() : 0);
        result = 31 * result + (vencimiento != null ? vencimiento.hashCode() : 0);
        result = 31 * result + (montoPeriodo != null ? montoPeriodo.hashCode() : 0);
        result = 31 * result + (montoXDebin != null ? montoXDebin.hashCode() : 0);
        result = 31 * result + (cantidad != null ? cantidad.hashCode() : 0);
        result = 31 * result + (detalle != null ? detalle.hashCode() : 0);
        result = 31 * result + (periodo != null ? periodo.hashCode() : 0);
        result = 31 * result + (prestacion != null ? prestacion.hashCode() : 0);
        result = 31 * result + (referencia != null ? referencia.hashCode() : 0);
        return result;
    }
}

==> sdd.debin-jar-0.5.13.jar: ar/com/sdd/debin/entity/Debin.java <==
package ar.com.sdd.debin.entity;

import ar.com.sdd.commons.rest.util.ManyMillisecondsDateDeserializer;
import ar.com.sdd.commons.rest.util.ManyMillisecondsDateSerializer;
import ar.com.sdd.debin.core.DebinConst;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;

import java.math.BigDecimal;
import java.util.Date;

@JsonIgnoreProperties(ignoreUnknown=true)
@JsonInclude(JsonInclude.Include.NON_NULL)
public class Debin {

    private String id;
    private Estado estado;

    @JsonDeserialize(using = ManyMillisecondsDateDeserializer.class)
    @JsonSerialize(using = ManyMillisecondsDateSerializer.class)
    private Date addDt;

    @JsonDeserialize(using = ManyMillisecondsDateDeserializer.class)
    @JsonSerialize(using = ManyMillisecondsDateSerializer.class)
    private Date fechaExpiracion;

    private Creacion creacion;
    private Vendedor vendedor;
    private Comprador comprador;
    private DebinConst.Moneda moneda;
    @JsonProperty("limite_cuotas")
    private Integer limiteCuotas;
    private BigDecimal importe;
    private String concepto;

    @JsonDeserialize(using = ManyMillisecondsDateDeserializer.class)
    @JsonSerialize(using = ManyMillisecondsDateSerializer.class)
    private Date vencimiento;

    private BigDecimal montoPeriodo;
    private BigDecimal montoXDebin;
    private Integer cantidad;
    private String detalle;
    private String periodo;
    private String prestacion;
    private String referencia;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public Estado getEstado() {
        return estado;
    }

    public void setEstado(Estado estado) {
        this.estado = estado;
    }

    public Date getAddDt() {
        return addDt;
    }

    public void setAddDt(Date addDt) {
        this.addDt = addDt;
    }

    public Date getFechaExpiracion() {
        return fechaExpiracion;
    }

    public void setFechaExpiracion(Date fechaExpiracion) {
        this.fechaExpiracion = fechaExpiracion;
    }

    public Creacion getCreacion() {
        return creacion;
    }

    public void setCreacion(Creacion creacion) {
        this.creacion = creacion;
    }

    public Vendedor getVendedor() {
        return vendedor;
    }

    public void setVendedor(Vendedor vendedor) {
        this.vendedor = vendedor;
    }

    public Comprador getComprador() {
        return comprador;
    }

    public void setComprador(Comprador comprador) {
        this.comprador = comprador;
    }

    public DebinConst.Moneda getMoneda() {
        return moneda;
    }

    public void setMoneda(DebinConst.Moneda moneda) {
        this.moneda = moneda;
    }

    public Integer getLimiteCuotas() {
        return limiteCuotas;
    }

    public void setLimiteCuotas(Integer limiteCuotas) {
        this.limiteCuotas = limiteCuotas;
    }

    public BigDecimal getImporte() {
        return importe;
    }

    public void setImporte(BigDecimal importe) {
        this.importe = importe;
    }

    public String getConcepto() {
        return concepto;
    }

    public void setConcepto(String concepto) {
        this.concepto = concepto;
    }

    public Date getVencimiento() {
        return vencimiento;
    }

    public void setVencimiento(Date vencimiento) {
        this.vencimiento = vencimiento;
    }

    public BigDecimal getMontoPeriodo() {
        return montoPeriodo;
    }

    public void setMontoPeriodo(BigDecimal montoPeriodo) {
        this.montoPeriodo = montoPeriodo;
    }

    public BigDecimal getMontoXDebin() {
        return montoXDebin;
    }

    public void setMontoXDebin(BigDecimal montoXDebin) {
        this.montoXDebin = montoXDebin;
    }

    public Integer getCantidad() {
        return cantidad;
    }

    public void setCantidad(Integer cantidad) {
        this.cantidad = cantidad;
    }

    public String getDetalle() {
        return detalle;
    }

    public void setDetalle(String detalle) {
        this.detalle = detalle;
    }

    public String getPeriodo() {
        return periodo;
    }

    public void setPeriodo(String periodo) {
        this.periodo = periodo;
    }

    public String getPrestacion() {
        return prestacion;
    }

    public void setPrestacion(String prestacion) {
        this.prestacion = prestacion;
    }

    public String getReferencia() {
        return referencia;
    }

    public void setReferencia(String referencia) {
        this.referencia = referencia;
    }

    @Override
    public String toString() {
        return "Debin ["
                + ((id != null) ? "id=" + id + ", " : "")
                + ((estado != null) ? "estado=" + estado + ", " : "")
                + ((addDt != null) ? "addDt=" + addDt + ", " : "")
                + ((fechaExpiracion != null) ? "fechaExpiracion=" + fechaExpiracion + ", " : "")
                + ((creacion != null) ? "creacion=" + creacion + ", " : "")
                + ((vendedor != null) ? "vendedor=" + vendedor + ", " : "")
                + ((comprador != null) ? "comprador=" + comprador + ", " : "")
                + ((moneda != null) ? "moneda=" + moneda + ", " : "")
                + ((importe != null) ? "importe=" + importe + ", " : "")
                + ((concepto != null) ? "concepto=" + concepto + ", " : "")
                + ((vencimiento != null) ? "vencimiento=" + vencimiento + ", " : "")
                + ((montoPeriodo != null) ? "montoPeriodo=" + montoPeriodo + ", " : "")
                + ((montoXDebin != null) ? "montoXDebin=" + montoXDebin + ", " : "")
                + ((cantidad != null) ? "cantidad=" + cantidad + ", " : "")
                + ((detalle != null) ? "detalle=" + detalle + ", " : "")
                + ((periodo != null) ? "periodo=" + periodo + ", " : "")
                + ((prestacion != null) ? "prestacion=" + prestacion + ", " : "")
                + ((referencia != null) ? "referencia=" + referencia : "")
                + "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        Debin debin = (Debin) o;

        if (id != null ? !id.equals(debin.id) : debin.id != null) return false;
        if (estado != null ? !estado.equals(debin.estado) : debin.estado != null) return false;
        if (addDt != null ? !addDt.equals(debin.addDt) : debin.addDt != null) return false;
        if (fechaExpiracion != null ? !fechaExpiracion.equals(debin.fechaExpiracion) : debin.fechaExpiracion != null)
            return false;
        if (creacion != null ? !creacion.equals(debin.creacion) : debin.creacion != null) return false;
        if (vendedor != null ? !vendedor.equals(debin.vendedor) : debin.vendedor != null) return false;
        if (comprador != null ? !comprador.equals(debin.comprador) : debin.comprador != null) return false;
        if (moneda != debin.moneda) return false;
        if (importe != null ? !importe.equals(debin.importe) : debin.importe != null) return false;
        if (concepto != null ? !concepto.equals(debin.concepto) : debin.concepto != null) return false;
        if (vencimiento != null ? !vencimiento.equals(debin.vencimiento) : debin.vencimiento != null) return false;
        if (montoPeriodo != null ? !montoPeriodo.equals(debin.montoPeriodo) : debin.montoPeriodo != null) return false;
        if (montoXDebin != null ? !montoXDebin.equals(debin.montoXDebin) : debin.montoXDebin != null) return false;
        if (cantidad != null ? !cantidad.equals(debin.cantidad) : debin.cantidad != null) return false;
        if (detalle != null ? !detalle.equals(debin.detalle) : debin.detalle != null) return false;
        if (periodo != null ? !periodo.equals(debin.periodo) : debin.periodo != null) return false;
        if (prestacion != null ? !prestacion.equals(debin.prestacion) : debin.prestacion != null) return false;
        return referencia != null ? referencia.equals(debin.referencia) : debin.referencia == null;
    }

    @Override
    public int hashCode() {
        int result = id != null ? id.hashCode() : 0;
        result = 31 * result + (estado != null ? estado.hashCode() : 0);
        result = 31 * result + (addDt != null ? addDt.hashCode() : 0);
        result = 31 * result + (fechaExpiracion != null ? fechaExpiracion.hashCode() : 0);
        result = 31 * result + (creacion != null ? creacion.hashCode() : 0);
        result = 31 * result + (vendedor != null ? vendedor.hashCode() : 0);
        result = 31 * result + (comprador != null ? comprador.hashCode() : 0);
        result = 31 * result + (moneda != null ? moneda.hashCode() : 0);
        result = 31 * result + (importe != null ? importe.hashCode() : 0);
        result = 31 * result + (concepto != null ? concepto.hashCode() : 0);
        result = 31 * result + (vencimiento != null ? vencimiento.hashCode() : 0);
        result = 31 * result + (montoPeriodo != null ? montoPeriodo.hashCode() : 0);
        result = 31 * result + (montoXDebin != null ? montoXDebin.hashCode() : 0);
        result = 31 * result + (cantidad != null ? cantidad.hashCode() : 0);
        result = 31 * result + (detalle != null ? detalle.hashCode() : 0);
        result = 31 * result + (periodo != null ? periodo.hashCode() : 0);
        result = 31 * result + (prestacion != null ? prestacion.hashCode() : 0);
        result = 31 * result + (referencia != null ? referencia.hashCode() : 0);
        return result;
    }
}
